/**
 * Copyright (c) 2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.commons.log;

import javax.jbi.messaging.MessageExchange;

/**
 * This class provides facilities for storing the flow attributes state into a message exchange.
 * 
 * Note that the object of class {@link FlowAttributes} is not stored itself to prevent classloading issues as the data
 * will be shared by multiple actors engaged in an exchange and they only share the JBI classloader which does not know
 * about {@link FlowAttributes}.
 *
 * @author vnoel
 *
 */
public class FlowAttributesExchangeHelper {

    private FlowAttributesExchangeHelper() {
    }

    public static FlowAttributes getFlowAttributes(final MessageExchange messageExchange) {
        final Object oI = messageExchange.getProperty(FlowAttributesExchangeProperties.FLOW_INSTANCE_ID);
        final Object oS = messageExchange.getProperty(FlowAttributesExchangeProperties.FLOW_STEP_ID);
        if (oS instanceof String && oI instanceof String) {
            return new FlowAttributes((String) oI, (String) oS);
        } else {
            return null;
        }
    }

    public static void setFlowAttributes(final MessageExchange messageExchange, final FlowAttributes attributes) {
        if (attributes != null) {
            messageExchange.setProperty(FlowAttributesExchangeProperties.FLOW_INSTANCE_ID,
                    attributes.getFlowInstanceId());
            messageExchange.setProperty(FlowAttributesExchangeProperties.FLOW_STEP_ID, attributes.getFlowStepId());
        }
    }

}
